diff --git a/i386/src/wl/sys/wl_linux.c b/i386/src/wl/sys/wl_linux.c
index dbd6e89..a0f785d 100644
--- a/i386/src/wl/sys/wl_linux.c
+++ b/i386/src/wl/sys/wl_linux.c
@@ -216,7 +216,7 @@ static const struct net_device_ops wl_netdev_ops =
 	.ndo_start_xmit = wl_start,
 	.ndo_get_stats = wl_get_stats,
 	.ndo_set_mac_address = wl_set_mac_address,
-	.ndo_set_multicast_list = wl_set_multicast_list,
+	.ndo_set_rx_mode = wl_set_multicast_list,
 	.ndo_do_ioctl = wl_ioctl
 };
 #endif 
@@ -1418,9 +1418,13 @@ static void
 _wl_set_multicast_list(struct net_device *dev)
 {
 	wl_info_t *wl;
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 34)
 	struct dev_mc_list *mclist;
 	int i;
-
+#else
+	struct netdev_hw_addr *ha;
+	int i=0;
+#endif
 	if (!dev)
 		return;
 	wl = WL_INFO(dev);
@@ -1431,15 +1435,22 @@ _wl_set_multicast_list(struct net_device *dev)
 
 	if (wl->pub->up) {
 		wl->pub->allmulti = (dev->flags & IFF_ALLMULTI)? TRUE: FALSE;
-
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 34)
 		for (i = 0, mclist = dev->mc_list; mclist && (i < dev->mc_count);
 			i++, mclist = mclist->next) {
+#else
+		netdev_for_each_mc_addr(ha, dev) {
+#endif
 			if (i >= MAXMULTILIST) {
 				wl->pub->allmulti = TRUE;
 				i = 0;
 				break;
 			}
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 34)
 			wl->pub->multicast[i] = *((struct ether_addr*) mclist->dmi_addr);
+#else
+			wl->pub->multicast[i] = *((struct ether_addr*) ha->addr);
+#endif
 		}
 		wl->pub->nmulticast = i;
 		wlc_set(wl->wlc, WLC_SET_PROMISC, (dev->flags & IFF_PROMISC));
